<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Terminalschriftart wählen</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Schriftart:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Drücken Sie &quot;%1&quot;, um das Terminal zu sehen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Nächste Registerkarte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Vorherige Registerkarte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Move Tab &amp;Left</source>
        <translation>Registerkarte nach &amp;links verschieben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Right</source>
        <translation>Registerkarte nach &amp;rechts verschieben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Terminal &amp;horizontal teilen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Terminal &amp;vertikal teilen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>Unterterminal &amp;schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>Aktives Terminal &amp;leeren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Keep window open when it loses focus</source>
        <translation>Fenster geöffnet lassen, wenn es den Fokus verliert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Vorherige Registerkarte im Verlauf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Nächste Registerkarte im Verlauf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Go to</source>
        <translation>Gehe zu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Oberes Unterterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Unteres Unterterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Linkes Unterterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Rechtes Unterterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copy &amp;Selection</source>
        <translation>Au&amp;swahl kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Paste Clip&amp;board</source>
        <translation>Zwischena&amp;blage einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste S&amp;election</source>
        <translation>Auswahl &amp;einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Zoom &amp;in</source>
        <translation>Ver&amp;größern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom rese&amp;t</source>
        <translation>Zoom zurückse&amp;tzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>&amp;Find...</source>
        <translation>&amp;Suchen…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Handle history...</source>
        <translation>Verlauf bearbeiten...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Sitzung speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>&amp;Load Session</source>
        <translation>Sitzung &amp;laden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Menü ein-/ausblenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Rename session</source>
        <translation>Sitzung umbenennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Neue Registerkarte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Neue Registerkarte aus &amp;Vorlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;horizontale Terminals</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;vertikale Terminals</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Terminal&amp;s</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>&amp;Close Tab</source>
        <translation>Registerkarte s&amp;chließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;New Window</source>
        <translation>&amp;Neues Fenster</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Einstellungen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Fensterrahmen &amp;ausblenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Regi&amp;sterkartenleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Toggle Bookmarks</source>
        <translation>Lesezeichen ein-/ausblenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Unten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Top</source>
        <translation>&amp;Oben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>&amp;Right</source>
        <translation>&amp;Rechts</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;Left</source>
        <translation>&amp;Links</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Darstellung der Registerkarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>&amp;None</source>
        <translation>&amp;Keine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;Darstellung der Bildlaufleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Block</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Unterstrich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Senkrechter Strich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Tastatur Cursor Form</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Exit QTerminal</source>
        <translation>QTerminal beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Do not ask again</source>
        <translation>Nicht erneut fragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Are you sure you want to exit?</source>
        <translation>Möchten Sie das Programm wirklich beenden?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Ein leichtgewichtiger und starker Multiplatform Terminal Emulator</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>LXQt Project</source>
        <translation>LXQt-Projekt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Development: </source>
        <translation>Entwicklung: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="813"/>
        <source>Emulation</source>
        <translation>Emulation</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Tastenkombinationen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Terminaleinstellungen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Aufklappen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Farbschema</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Stil der Bedienelemente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Position der Bildlaufleiste</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Registerkartenposition</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Menüleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Aktuelles Terminal einrahmen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Transparenz der Anwendung</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Transparenz des Terminals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Starte mit Vorlage:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Keine (einzelnes Terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 horizontale Terminals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 vertikale Terminals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 Terminals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Fenstertitel ändern anhand aktuellem Terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Fenstersymbol ändern anhand aktuellem Terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Aktiviere bidirektionale Textunterstützung</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Hintergrundbild:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Terminalgröße beim Skalieren anzeigen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Schaltfläche Schließen auf jeder Registerkarte anzeigen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Terminalrand</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>In der Schriftart enthaltene Zeichen für die Boxzeichnung verwenden</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Beschleuniger werden mit Alt aktiviert und können das Terminal stören.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Kein Menüleisten-Beschleuniger</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Aktion nach dem Einfügen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Confirm multiline paste</source>
        <translation>Einfügen mehrerer Zeilen bestätigen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="651"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Zeilenumbrüche am Ende des eingefügten Textes entfernen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="747"/>
        <source>Open new terminals in current working directory</source>
        <translation>Neues Terminal im aktuellen Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="682"/>
        <source>Save Size when closing</source>
        <translation>Fenstergröße beim Beenden speichern</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Save Position when closing</source>
        <translation>Fensterposition beim Beenden speichern</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Ask for confirmation when closing</source>
        <translation>Beim Schließen eines Fensters nachfragen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Unbegrenzter Verlauf</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Verlaufsgröße (in Zeilen)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Default $TERM</source>
        <translation>Standard $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="694"/>
        <source>Start with this size:</source>
        <translation>Mit dieser Größe beginnen:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Hintergrund-Modus:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Kein</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Strecken</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Vergrößerung</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Fit</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Zentrieren</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Gibt an, ob Rahmenzeichen von QTerminal intern oder von zugrunde liegenden Bibliotheken gezeichnet werden soll.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Schaltet Verwendung fettgedruckter Schriftarten für intensive Farben um</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Fettgedrucktes Schriftbild für intensive Farben verwenden</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Fensterrahmen &amp;ausblenden</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="822"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Welches Verhalten emuliert wird. Beachte, dass das nicht mit deinem Betriebssystem übereinstimmen muss.&lt;/p&gt;&lt;p&gt;Wenn du unsicher bist, nutze die &lt;span style=&quot; font-weight:600;&quot;&gt;Standard-Emulation&lt;/span&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="800"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Dieser Befehl wird mit einem Argument ausgeführt, das den Dateinamen eines tempfiles enthält, welches die Scrollback-Historie enthält</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="803"/>
        <source>Handle history command</source>
        <translation>Verlaufsbefehl bearbeiten</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="701"/>
        <location filename="../forms/propertiesdialog.ui" line="715"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="722"/>
        <source>Get current size</source>
        <translation>Aktuelle Größe ermitteln</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Neuen Tab rechts von aktivem Tab öffnen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="754"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Falls deaktiviert, wird ein neuer Reiter ganz rechts geöffnet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="658"/>
        <source>Close tab on middle-click</source>
        <translation>Tab mit Mittelklick schließen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Das Beenden des Einfüge-Modus in Klammern erzwingen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Mit dem geklammerten Einfüge-Modus ist es möglich, längere Zeichenketten einzufügen.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>Audible bell</source>
        <translation>Audiosignal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="846"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Bearbeiten eines Tastenkürzels:
1. Doppelklick auf die Zuweisung
2. Drücken und Loslassen der neuen Tastenkombination
3. Klcke auf das Tastenkürzel oder drücke Enter

Zum entfernen/deaktivieren eines Tastenkürzel, bei Schritt 2 nur eine Modifier-Taste (z. B. Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="900"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Auf der horizontalen Registerkartenleiste wird eine Sperrschaltfläche angezeigt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="903"/>
        <source>Keep window open when it loses focus</source>
        <translation>Fenster geöffnet lassen, wenn es den Fokus verliert</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="921"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1029"/>
        <source>Edit bookmark file contents</source>
        <translation>Inhalt der Lesezeichendatei bearbeiten</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Enable bookmarks</source>
        <translation>Lesezeichen aktivieren</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="997"/>
        <source>Bookmark file</source>
        <translation>Lesezeichendatei</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="876"/>
        <source>Shortcut</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="881"/>
        <source>Key</source>
        <translation>Taste</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Registerkartenleiste bei einer Registerkarte ausblenden</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Ändern...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Schreibmarkenform</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Feste Registerkartenbreite:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Show on start</source>
        <translation>Beim Start anzeigen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="962"/>
        <source>Shortcut:</source>
        <translation>Tastenkürzel:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1010"/>
        <source>Find...</source>
        <translation>Suchen...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Sie können Ihre eigene Lesezeichendatei angeben. Dies erlaubt einfachen Austausch mit Werkzeugen wie OwnCloud oder DropBox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Keine Bildlaufleiste</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Block</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Unterstrich</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Senkrechter Strich</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Kein Verschieben</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Nach oben rollen</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Nach unten rollen</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="268"/>
        <source>Examples</source>
        <translation>Beispiele</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Bilder (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="511"/>
        <source>Open bookmarks file</source>
        <translation>Lesezeichendatei öffnen</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="513"/>
        <source>XML files (*.xml)</source>
        <translation>XML-Dateien (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Möchten Sie diese Lesezeichendatei überschreiben?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Der Name der Lesezeichendatei endet nicht auf &quot;.xml&quot;
Sind Sie sicher, dass Sie sie überschreiben wollen?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Es können keine Lesezeichen in diese Datei geschrieben werden:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="203"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Systemstandard</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="420"/>
        <source>Choose a background image</source>
        <translation>Wähle ein Hintergrundbild</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Synchronisierte Lesezeichen</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="80"/>
        <location filename="../tabwidget.cpp" line="234"/>
        <source>Shell No. %1</source>
        <translation>Shell Nr. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="202"/>
        <source>Tab name</source>
        <translation>Registerkartenname</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>New tab name:</source>
        <translation>Neuer Registerkartenname:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>Select new tab title color</source>
        <translation>Farbe des neuen Registerkartentitels auswählen</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="252"/>
        <source>Close session</source>
        <translation>Sitzung schließen</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Change title color</source>
        <translation>Titelfarbe ändern</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Sitzung laden</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Liste gespeicherter Sitzungen:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Aktionen</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Über...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Über &amp;Qt...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Hauptfenster</translation>
    </message>
</context>
</TS>
